@@ -500,6 +500,7 @@ Seat ExtractorPostprocessorPrivate::processSeat(Seat seat) const
     seat.setSeatSection(seat.seatSection().simplified());
     seat.setSeatRow(seat.seatRow().simplified());
     seat.setSeatNumber(seat.seatNumber().simplified());
+    seat.setSeatingType(seat.seatingType().simplified());
     return seat;
 }
 
@@ -598,7 +599,7 @@ PostalAddress ExtractorPostprocessorPrivate::processAddress(PostalAddress addr,
         if (util->ParseAndKeepRawInput(phoneStr, "ZZ", &number) == i18n::phonenumbers::PhoneNumberUtil::NO_PARSING_ERROR) {
             std::string isoCode;
             util->GetRegionCodeForNumber(number, &isoCode);
-            if (!isoCode.empty()) {
+            if (!isoCode.empty() && isoCode != "ZZ") {
                 addr.setAddressCountry(QString::fromStdString(isoCode));
             }
         }
